@@ -143,11 +143,8 @@ class VideoInfoWindow(QMainWindow, Ui_VideoInfoWindow):
         """
         videoTitle = self.video.title.text
         try:
-            self.toggleBusy(True)
             videoPlaybackWindow = VideoPlaybackWindow(self, video = self.video)
-            self.connect(videoPlaybackWindow, SIGNAL("playing()"), lambda isBusy = False: self.toggleBusy(isBusy))
         except:
-            self.toggleBusy(False)
             QMaemo5InformationBox.information(self, "Unable to play video")
 
     def downloadVideo(self):
