@@ -140,7 +140,11 @@ class YouTubeDataService(object):
 
     @staticmethod
     def getVideoEntry(videoId):
-        return YouTubeDataService.ytService.GetYouTubeVideoEntry(videoId)
+        try:
+            videoEntry = YouTubeDataService.ytService.GetYouTubeVideoEntry(videoId)
+        except:
+            videoEntry = YouTubeDataService.ytService.GetYouTubeVideoEntry(video_id = videoId)
+        return videoEntry
 
     @staticmethod
     def getVideoThumbnail(thumbUrl):
@@ -174,6 +178,8 @@ class YouTubeDataService(object):
     def getVideoUrl(video,  videoFormat = "18"):
         """
         Returns the YouTube video url for download or playback.
+        In the case of a download, if the user-chosen format is not 
+        available, the next available format will be used.
         """
         videoUrl = ""        
         if "playlists" in video.id.text:
@@ -187,7 +193,7 @@ class YouTubeDataService(object):
             videoInfo = parse_qs(videoInfoWebpage)
             if 'token' in videoInfo:
                 videoToken = urllib.unquote_plus(videoInfo['token'][0])
-                formatList = ['18', '17']
+                formatList = ['22', '35', '34', '18', '17']
                 for format in formatList[formatList.index(videoFormat):]:
                     videoUrl = 'http://www.youtube.com/get_video?video_id=%s&t=%s&eurl=&el=&ps=&asv=&fmt=%s' % (videoId, videoToken,  format)
                     videoLength = urllib.urlopen(videoUrl).info()["Content-Length"]
@@ -453,8 +459,11 @@ class DownloadTask(QThread):
         self.connect(self,  SIGNAL("finished()"),  YouTubeVideoDownloader.run)
 
         # Create the target filename
-
-        self.filename = "%s/%s.mp4" % (VideoDownloadSettings.downloadFolder, unicode(re.sub('[:/|\\\\]', "-", self.video.media.title.text), "utf-8"))
+        if VideoDownloadSettings.downloadFormat in ("34", "35", "22"):
+            formatExt = "HQ"
+            self.filename = "%s/%s-%s.mp4" % (VideoDownloadSettings.downloadFolder, unicode(re.sub('[:/|\\\\]', "-", self.video.media.title.text), "utf-8"), formatExt)
+        else:
+            self.filename = "%s/%s.mp4" % (VideoDownloadSettings.downloadFolder, unicode(re.sub('[:/|\\\\]', "-", self.video.media.title.text), "utf-8"))
         self.tempname = self.filename + '.partial'
 
         self.totalSize = 0
